==> jbossws-cxf-client-4.3.1.Final-redhat-1-sources.jar: org/jboss/wsf/stack/cxf/extensions/security/PasswordCallbackHandler.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.stack.cxf.extensions.security;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import javax.security.auth.callback.Callback;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.callback.UnsupportedCallbackException;
import org.apache.ws.security.WSPasswordCallback;

public class PasswordCallbackHandler implements CallbackHandler
{

   private Map<String, String> passwords = new HashMap<String, String>();

   public PasswordCallbackHandler(Map<String, String> initMap)
   {
      passwords.putAll(initMap);
   }

   /**
    * It attempts to get the password from the private 
    * alias/passwords map.
    */
   public void handle(Callback[] callbacks) throws IOException, UnsupportedCallbackException
   {
      for (int i = 0; i < callbacks.length; i++)
      {
         final Callback c = callbacks[i];
         if (c != null && c instanceof WSPasswordCallback) {
            final WSPasswordCallback pc = (WSPasswordCallback)c;
   
            String pass = passwords.get(pc.getIdentifier());
            if (pass != null)
            {
               pc.setPassword(pass);
               return;
            }
         }
      }
   }

   /**
    * Add an alias/password pair to the callback mechanism.
    */
   public void setAliasPassword(String alias, String password)
   {
      passwords.put(alias, password);
   }
}

==> jbossws-cxf-client-5.1.10.Final-redhat-1-sources.jar: org/jboss/wsf/stack/cxf/extensions/security/PasswordCallbackHandler.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.stack.cxf.extensions.security;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import javax.security.auth.callback.Callback;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.callback.UnsupportedCallbackException;

import org.apache.wss4j.common.ext.WSPasswordCallback;

public class PasswordCallbackHandler implements CallbackHandler
{

   private Map<String, String> passwords = new HashMap<String, String>();

   public PasswordCallbackHandler(Map<String, String> initMap)
   {
      passwords.putAll(initMap);
   }

   /**
    * It attempts to get the password from the private 
    * alias/passwords map.
    */
   public void handle(Callback[] callbacks) throws IOException, UnsupportedCallbackException
   {
      for (int i = 0; i < callbacks.length; i++)
      {
         final Callback c = callbacks[i];
         if (c != null && c instanceof WSPasswordCallback) {
            final WSPasswordCallback pc = (WSPasswordCallback)c;
   
            String pass = passwords.get(pc.getIdentifier());
            if (pass != null)
            {
               pc.setPassword(pass);
               return;
            }
         }
      }
   }

   /**
    * Add an alias/password pair to the callback mechanism.
    */
   public void setAliasPassword(String alias, String password)
   {
      passwords.put(alias, password);
   }
}
